@@ -23,11 +23,10 @@ CreateGrid <- function (w, resolution)
   boundingBox <- bbox(w)
   rounder <- boundingBox %% resolution
   boundingBox[,1] <- boundingBox[,1] - rounder[,1]
-  roundermax <- resolution - rounder[,2]
   boundingBox[,2] <- boundingBox[,2] + resolution - rounder[,2]
-  boxCoordX <- seq(from = boundingBox[1,1], to = boundingBox[1,2], 
+  boxCoordX <- seq(from = boundingBox[1,1] - resolution*10, to = boundingBox[1,2]+resolution*10, 
                    by = resolution)
-  boxCoordY <- seq(from = boundingBox[2,1], to = boundingBox[2,2], 
+  boxCoordY <- seq(from = boundingBox[2,1] - resolution * 10, to = boundingBox[2,2] + resolution*10, 
                    by = resolution)
   spatGrid <- expand.grid(boxCoordX, boxCoordY)
   idSeq <- seq(1, nrow(spatGrid), 1)
@@ -89,7 +88,7 @@ CreateDistMatrix  <- function(knownpts,
     nu <- nrow(unknownpts)
     if(nk * nu > 100000000 | nu > 10000000 | nk > 10000000){
       if (interactive()){
-        cat("Do you really want to compute potentials values (from", nk , 
+        cat("Do you really want to this distance matrix (from", nk , 
             "known points to", nu,"estimated values) ? \n 
             (It seems to be a heavy computation.) [y/n]" )
         z <- readLines(con = stdin(), n = 1) 
